@@ -1,14 +1,23 @@
-;# $Id: configure.pl,v 3.0.1.2 1994/01/24 14:23:21 ram Exp $
+;# $Id: configure.pl 25 2008-05-28 11:19:25Z rmanfredi $
 ;#
-;#  Copyright (c) 1991-1993, Raphael Manfredi
+;#  Copyright (c) 1991-1997, 2004-2006, Raphael Manfredi
 ;#  
 ;#  You may redistribute only under the terms of the Artistic Licence,
 ;#  as specified in the README file that comes with the distribution.
 ;#  You may reuse parts of this distribution only within the terms of
 ;#  that same Artistic Licence; a copy of which may be found at the root
-;#  of the source tree for dist 3.0.
+;#  of the source tree for dist 4.0.
 ;#
 ;# $Log: configure.pl,v $
+;# Revision 3.0.1.5  1995/01/30  14:47:15  ram
+;# patch49: removed old "do name()" routine call constructs
+;#
+;# Revision 3.0.1.4  1995/01/11  15:40:02  ram
+;# patch45: now allows @if statements for the add.Config_sh unit inclusion
+;#
+;# Revision 3.0.1.3  1994/05/06  15:21:23  ram
+;# patch23: cleaned up the 'prepend' command
+;#
 ;# Revision 3.0.1.2  1994/01/24  14:23:21  ram
 ;# patch16: new general <\$variable> macro substitutions in wiped units
 ;#
@@ -101,7 +110,9 @@ sub process_command {
 			s/<PACKAGENAME>/$package/g;
 			s/<MAINTLOC>/$maintloc/g;
 			s/<VERSION>/$version/g;			# This is metaconfig's version
-			s/<PATCHLEVEL>/$patchlevel/g;	# And patchlevel information
+			s/<REVISION>/$revision/g;		# And revision information
+			warn "\"$file\": usage of <PATCHLEVEL> is deprecated\n"
+				if s/<PATCHLEVEL>/$patchlevel/g;
 			s/<DATE>/$date/g;
 			s/<BASEREV>/$baserev/g;
 			s/<\$(\w+)>/eval("\$$1")/ge;	# <$var> -> $var substitution
@@ -133,7 +144,7 @@ sub process_command {
 	# variable are added, the conditional ones are skipped.
 	elsif ($cmd eq 'add.Config_sh') {
 		while (<UNIT>) {
-			print CONFIGURE unless &skipped;
+			print CONFIGURE unless &skipped || !&interpret($_);
 		}
 		for (sort @Master) {
 			if (/^\?(\w+):/) {
@@ -199,12 +210,10 @@ sub process_command {
 	}
 	
 	# The 'prepend' command will add the content of the target to
-	# the current file (held in $file, the one which UNIT referes to),
+	# the current file (held in $file, the one which UNIT refers to),
 	# if the file is not empty.
 	elsif ($cmd eq 'prepend') {
-		if (! -w $file) {
-			warn("Cannot write into $file.\n");
-		} elsif (!eof(UNIT)) {
+		if (-s $file) {
 			open(PREPEND, ">.prepend") ||
 				die "Can't create .MT/.prepend.\n";
 			open(TARGET, $Unit{$target}) ||
@@ -212,7 +221,7 @@ sub process_command {
 			while (<TARGET>) {
 				print PREPEND unless &skipped;
 			}
-			print PREPEND <UNIT>;
+			print PREPEND <UNIT>;	# Now add original file contents
 			close PREPEND;
 			close TARGET;
 			rename('.prepend', $file) ||
@@ -224,7 +233,7 @@ sub process_command {
 	else {
 		die "Unrecognized command from Makefile: $cmd\n";
 	}
-	do check_state();		# Make sure there are no pending statements
+	&check_state;		# Make sure there are no pending statements
 	close UNIT;
 }
 
